@@ -22,10 +22,10 @@ import yaml
 import click
 
 from peekingduck.runner import Runner
-from peekingduck.utils.logger import setup_logger
+from peekingduck.utils.logger import LoggerSetup
 from peekingduck import __version__
 
-setup_logger()
+LoggerSetup()
 logger = logging.getLogger(__name__)  # pylint: disable=invalid-name
 
 
@@ -96,3 +96,50 @@ def run(config_path: str, node_config: str) -> None:
 
     runner = Runner(config_path, node_config, "src")
     runner.run()
+
+
+@cli.command()
+@click.argument("type_name", required=False)
+def nodes(type_name: str = None) -> None:
+    """
+    Lists available nodes in PeekingDuck. When no argument is given, all
+    available nodes will be listed. When the node type is given as an argument
+    , all available nodes in the specified node type will be listed.
+
+    Args:
+        type_name (str): input, model, dabble, draw or output
+    """
+
+    url_prefix = "https://peekingduck.readthedocs.io/en/stable/peekingduck.pipeline.nodes."
+    url_postfix = ".Node.html#peekingduck.pipeline.nodes."
+
+    if type_name is None:
+        type_of_node = ["input", "model", "dabble", "draw", "output"]
+    else:
+        type_of_node = [type_name]
+
+    dir_path = os.path.dirname(os.path.realpath(__file__))
+    configs_dir = os.path.join(dir_path, 'configs')
+
+    for node_type in type_of_node:
+        type_dir = os.path.join(configs_dir, node_type)
+        files_name = os.listdir(type_dir)
+
+        click.secho("\nPeekingDuck has the following ", bold=True, nl=False)
+        click.secho(f"{node_type} ", fg="red", bold=True, nl=False)
+        click.secho("nodes:", bold=True)
+
+        node_names = [file_name.split(".")[0] for file_name in files_name]
+        max_length = len(max(node_names, key=len))
+        for num, node_name in enumerate(node_names):
+            url = (
+                f" {url_prefix}{node_type}.{node_name}{url_postfix}"
+                f"{node_type}.{node_name}.Node"
+            )
+
+            click.secho(f"{num + 1}:", nl=False)
+            click.secho(f"{node_name: <{max_length + 1}}", bold=True, nl=False)
+            click.secho("Info:", fg="yellow", nl=False)
+            click.secho(url)
+
+    click.secho("\n")
