@@ -28,7 +28,9 @@ class Node(AbstractNode):
 
     The EfficientDet node is capable of detecting objects from 80 categories.
     The table of categories can be found :term:`here <object detection
-    indices>`. EfficientDet node has five levels of compound coefficient
+    indices>`.
+
+    EfficientDet node has five levels of compound coefficient
     (0 - 5). A higher compound coefficient will scale up all dimensions of the
     backbone network width, depth, and input resolution, which results in better
     performance but slower inference time. The default compound coefficient is
